AddCustomRequestHeaderCommand (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.commands
Class AddCustomRequestHeaderCommand

    java.lang.Object
      org.openqa.selenium.server.commands.Command
          org.openqa.selenium.server.commands.AddCustomRequestHeaderCommand

    public class AddCustomRequestHeaderCommand

extends Command

Constructor Summary
`AddCustomRequestHeaderCommand(java.lang.String key, java.lang.String value)`

Method Summary
`java.lang.String` | `execute()`
`static java.util.Map<java.lang.String,java.lang.String>` | `getHeaders()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### AddCustomRequestHeaderCommand

    public AddCustomRequestHeaderCommand(java.lang.String key,
                                         java.lang.String value)

Method Detail

### execute

    public java.lang.String execute()

  Specified by:
    `execute` in class `Command`

### getHeaders

    public static java.util.Map<java.lang.String,java.lang.String> getHeaders()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.